==========
LangToJson
==========


.. image:: https://img.shields.io/pypi/v/langtojson.svg
        :target: https://pypi.python.org/pypi/langtojson

.. image:: https://img.shields.io/travis/Ars2014/langtojson.svg
        :target: https://travis-ci.com/Ars2014/langtojson

.. image:: https://readthedocs.org/projects/langtojson/badge/?version=latest
        :target: https://langtojson.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/Ars2014/langtojson/shield.svg
     :target: https://pyup.io/repos/github/Ars2014/langtojson/
     :alt: Updates



Tool to convert .lang files to JSON


* Free software: MIT license


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
